<?php
/**
 * ClubCar functions and definitions
 *
 * @package ClubCar
 */

/**
 * ClubCar Theme Setup
 */
function clubcar_setup() {

	// Meta Title.
	add_theme_support( 'title-tag' );

	// Automatic Feed Links.
	add_theme_support( 'automatic-feed-links' );

	// Logo Support.
	add_theme_support(
		'custom-logo',
		array(
			'width'       => 215,
			'height'      => 38,
			'flex-width'  => true,
			'flex-height' => true,
			'header-text' => array(
				'site-title',
				'site-description',
			),
		)
	);

	// Featured Image.
	add_theme_support( 'post-thumbnails' );

	// Align Wide
	add_theme_support( 'align-wide' );

	// Block styles
	add_theme_support( 'wp-block-styles' );

	// Responsive embeds
	add_theme_support( 'responsive-embeds' );

	// HTML5
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		'style',
		'script'
	) );

	// Language Support.
	load_theme_textdomain( 'clubcar', get_template_directory() . '/languages' );

	// Header Image.
	$clubcar_args = array(
		'flex-width'         => true,
		'width'              => 2100,
		'flex-height'        => true,
		'height'             => 900,
		'default-text-color' => '#fff',
	);
	add_theme_support( 'custom-header', $clubcar_args );

	// Content Width.
	if ( ! isset( $content_width ) ) {
		$content_width = 1170;
	}
}
add_action( 'after_setup_theme', 'clubcar_setup' );

/**
 * Color / Social Customizer
 *
 * @param array $clubcar_wp_customize Theme Colors & Social Media.
 */
function clubcar_customize_register( $clubcar_wp_customize ) {
	$clubcar_colors   = array();
	$clubcar_colors[] = array(
		'slug'    => 'default_color',
		'default' => '#bebf3a',
		'label'   => __( 'Default Color ', 'clubcar' ),
	);

	foreach ( $clubcar_colors as $clubcar_color ) {
		$clubcar_wp_customize->add_setting(
			$clubcar_color['slug'],
			array(
				'default'           => $clubcar_color['default'],
				'type'              => 'theme_mod',
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);
		$clubcar_wp_customize->add_control(
			new WP_Customize_Color_Control(
				$clubcar_wp_customize,
				$clubcar_color['slug'],
				array(
					'label'    => $clubcar_color['label'],
					'section'  => 'colors',
					'settings' => $clubcar_color['slug'],
				)
			)
		);
	}

	$clubcar_wp_customize->add_panel(
		'widget_images',
		array(
			'priority'       => 70,
			'theme_supports' => '',
			'title'          => esc_html__( 'Widget Images', 'clubcar' ),
			'description'    => esc_html__( 'Set background images for certain widgets.', 'clubcar' ),
		)
	);

	$clubcar_wp_customize->add_section(
		'contact_background',
		array(
			'title'    => esc_html__( 'Contact Background', 'clubcar' ),
			'panel'    => 'widget_images',
			'priority' => 20,
		)
	);

	$clubcar_wp_customize->add_setting(
		'contact_bg',
		array(
			'flex-width'  => true,
			'width'       => 2100,
			'flex-height' => true,
			'height'      => 900,
		)
	);

	$clubcar_wp_customize->add_control(
		new WP_Customize_Image_Control(
			$clubcar_wp_customize,
			'contact_background_image',
			array(
				'label'    => esc_html__( 'Add Contact Background Here, the width should be approx 2100px', 'clubcar' ),
				'section'  => 'contact_background',
				'settings' => 'contact_bg',
			)
		)
	);

	$clubcar_wp_customize->add_section(
		'sociallinks',
		array(
			'title'       => __( 'Social Links', 'clubcar' ),
			'description' => __( 'Add Your Social Links Here.', 'clubcar' ),
			'priority'    => '900',
		)
	);

	$clubcar_wp_customize->add_setting(
		'clubcar_facebooklink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_facebooklink',
		array(
			'label'   => __( 'Facebook URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_twitterlink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_twitterlink',
		array(
			'label'   => __( 'Twitter URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_pinterestlink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_pinterestlink',
		array(
			'label'   => __( 'Pinterest URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_instagramlink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_instagramlink',
		array(
			'label'   => __( 'Instagram URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_linkedinlink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_linkedinlink',
		array(
			'label'   => __( 'LinkedIn URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_youtubelink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_youtubelink',
		array(
			'label'   => __( 'YouTube URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_vimeo',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_vimeo',
		array(
			'label'   => __( 'Vimeo URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_tumblrlink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_tumblrlink',
		array(
			'label'   => __( 'Tumblr URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
	$clubcar_wp_customize->add_setting(
		'clubcar_flickrlink',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$clubcar_wp_customize->add_control(
		'clubcar_flickrlink',
		array(
			'label'   => __( 'Flickr URL', 'clubcar' ),
			'section' => 'sociallinks',
		)
	);
}
add_action( 'customize_register', 'clubcar_customize_register' );

/**
 * Includes Plugin Admin
 */
require_once ABSPATH . 'wp-admin/includes/plugin.php';

/**
 * Bootstrap
 */
function clubcar_bootstrap() {
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/bootstrap/bootstrap.min.css', array(), '0.0.1' );
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/fontawesome/css/fontawesome.min.css', array(), '0.0.1' );
	wp_enqueue_style( 'clubcar-googlefonts', clubcar_google_fonts_url(), array(), '0.0.1' );
	wp_enqueue_style( 'clubcar-style', get_stylesheet_uri(), array(), '0.0.1' );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/bootstrap/bootstrap.min.js', array( 'jquery' ), '0.0.1', true );
	wp_enqueue_script( 'clubcar-script', get_template_directory_uri() . '/js/script.min.js', array( 'jquery' ), '0.0.1', true );
}
add_action( 'wp_enqueue_scripts', 'clubcar_bootstrap' );

/**
 * Google Font
 */
function clubcar_google_fonts_url() {
	$font_families = array( 'Jost:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900' );
	$query_args    = array(
		'family' => rawurlencode( implode( '|', $font_families ) ),
		'subset' => rawurlencode( 'latin,latin-ext' ),
	);
	$fonts_url     = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	return apply_filters( 'clubcar_google_fonts_url', $fonts_url );
}

/**
 * Navigation
 */
function clubcar_register_menu() {
	register_nav_menus(
		array(
			'primary' => esc_html__( 'Top Primary Menu', 'clubcar' ),
		)
	);
}
add_action( 'init', 'clubcar_register_menu' );

/**
 * Bootstrap Navigation
 */
function clubcar_bootstrap_menu() {
	wp_nav_menu(
		array(
			'theme_location' => 'primary',
			'depth'          => 2,
			'menu_class'     => 'nav navbar-nav justify-content-end',
			'fallback_cb'    => 'WP_Bootstrap_Navwalker::fallback',
			'walker'         => new WP_Bootstrap_Navwalker(),
		)
	);
}
require get_template_directory() . '/inc/class-wp-bootstrap-navwalker.php';

/**
 * WooCommerce Support
 */
function clubcar_woocommerce_support() {
	add_theme_support( 'woocommerce' );
}
add_action( 'after_setup_theme', 'clubcar_woocommerce_support' );

remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display', 10 );
add_action( 'woocommerce_after_cart', 'woocommerce_cross_sell_display', 10 );

/**
 * WooCommerce Cart Count
 */
function clubcar_woocommerce_cart_count() {
	if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
		$clubcar_count = WC()->cart->cart_contents_count;
		?>
		<a href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_attr__( 'View your shopping cart', 'clubcar' ); ?>" class="w-100 h-100 rounded-circle d-block">
			<i class="fas fa-shopping-bag"></i>
		<?php if ( $clubcar_count > 0 ) { ?>
			<span class="woocommerce-cart-contents-count"><?php echo esc_html( $clubcar_count ); ?></span>
		<?php } ?>
		</a>
		<?php
	}
}
add_action( 'clubcar_header_top', 'clubcar_woocommerce_cart_count' );

/**
 * WooCommerce Cart Count
 *
 * @param array $clubcar_fragments Cart Count.
 */
function clubcars_add_to_cart_fragment( $clubcar_fragments ) {
	ob_start();
	$clubcar_count = WC()->cart->cart_contents_count;
	?>
	<a href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_attr( 'View your shopping cart', 'clubcar' ); ?>" class="w-100 h-100 rounded-circle d-block">
		<i class="fas fa-shopping-bag"></i>
	<?php if ( $clubcar_count > 0 ) { ?>
		<span class="woocommerce-cart-contents-count"><?php echo esc_html( $clubcar_count ); ?></span>
	<?php } ?>
	</a>
	<?php
	$clubcar_fragments['.woocommerce-cart-contents a'] = ob_get_clean();
	return $clubcar_fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'clubcars_add_to_cart_fragment' );

/**
 * Header Style
 */
function clubcar_header_style() {
	if ( ! display_header_text() ) {
		echo '
		<style type="text/css">
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px 1px 1px 1px);
				clip: rect(1px, 1px, 1px, 1px);
			}
		</style>
		';
	}
}
add_action( 'wp_head', 'clubcar_header_style' );

/**
 * Custom Colors
 */
function clubcar_customizer_css() {
	$clubcar_default_color     = get_theme_mod( 'default_color' );
	$clubcar_header_text_color = get_header_textcolor();
	?>
	<style type="text/css">
		.site-header .site-header-info h1,
		.site-header .site-header-info p {
		    color: #<?php echo esc_attr( $clubcar_header_text_color ); ?>;
		}

	<?php if ( $clubcar_default_color ) : ?>
		.btn-search,
		.btn-submit,
		.cursor.cursor-1,
		.top-bar,
		.navbar .navbar-toggler .navbar-toggler-line,
		.site-header .site-header-info h1:before,
		.site-header .site-header-extra,
		.site-header .site-header-extra .site-header-extra-arrow,
		.site-header .site-header-extra .site-header-extra-image .site-header-extra-image-overlay:before,
		.content-index .post-item,
		.post-item .post-overlay:before,
		.post-item .post-message a.more-link span.more-link-arrow,
		.post-item .post-categories-list li a,
		.post-tags .tags a,
		.nav-links .page-numbers.current,
		.nav-links .page-numbers:hover,
		.nav-links .page-numbers:focus,
		.nav-links .prev.page-numbers,
		.nav-links .next.page-numbers,
		.comment .reply a,
		.woocommerce span.onsale,
		.woocommerce .products .product .button,
		.woocommerce .products .product a.added_to_cart,
		.woocommerce #respond input#submit.alt,
		.woocommerce a.button.alt,
		.woocommerce a.button.alt:hover,
		.woocommerce a.button.alt:focus,
		.woocommerce button.button.alt,
		.woocommerce button.button.alt:hover,
		.woocommerce button.button.alt:focus,
		.woocommerce input.button.alt,
		.woocommerce #respond input#submit,
		.woocommerce a.button,
		.woocommerce button.button,
		.woocommerce input.button,
		.sidebar .sidebar-button .btn-sidebar {
		    background-color: <?php echo esc_attr( $clubcar_default_color ); ?>;
		}

		.cursor.cursor-2 {
		    border-color: <?php echo esc_attr( $clubcar_default_color ); ?>;
		}

		a:hover,
		a:focus,
		.woocommerce-cart-contents i,
		.post-item .post-title h2 a:hover,
		.post-item .post-title h2 a:focus {
		    color: <?php echo esc_attr( $clubcar_default_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
add_action( 'wp_head', 'clubcar_customizer_css' );

/**
 * Widgets
 */
function clubcar_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Primary Sidebar', 'clubcar' ),
			'id'            => 'primary_sidebar',
			'before_widget' => '<div class="sidebar-item">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2>',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Header', 'clubcar' ),
			'id'            => 'header-sidebar',
			'before_widget' => '<div class="header">',
			'after_widget'  => '</div>',
			'before_title'  => '<h1>',
			'after_title'   => '</h1>',
		)
	);
}
add_action( 'widgets_init', 'clubcar_widgets_init' );

/**
 * Post Read More
 *
 * @param array $link Show more link.
 */
function clubcar_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf(
		'<p class="link-more"><a href="%1$s" class="more-link fw-bold">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		// translators: %s containing the title of the post or page.
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'clubcar' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'clubcar_excerpt_more' );

/**
 * Excerp length
 *
 * @param array $length Exerpt length.
 */
function clubcar_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'clubcar_excerpt_length', 999 );


/**
 * Bootstrap Images img-fluid
 *
 * @param array $html Html code for image with Bootstrap class.
 */
function clubcar_bootstrap_responsive_images( $html ) {
	$classes = 'img-fluid';
	if ( preg_match( '/<img.*? class="/', $html ) ) {
		$html = preg_replace( '/(<img.*? class=".*?)(".*?\/>)/', '$1 ' . $classes . ' $2', $html );
	} else {
		$html = preg_replace( '/(<img.*?)(\/>)/', '$1 class="' . $classes . '" $2', $html );
	}
	return $html;
}
add_filter( 'the_content', 'clubcar_bootstrap_responsive_images', 10 );
add_filter( 'post_thumbnail_html', 'clubcar_bootstrap_responsive_images', 10 );

/**
 * Comment Reply
 */
function clubcar_comment_reply() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'clubcar_comment_reply' );

/**
 * Bootstrap Comment Form
 *
 * @param array $clubcar_fields Comment Form Fields.
 */
function clubcar_comment_form_fields( $clubcar_fields ) {
	$clubcar_commenter = wp_get_current_commenter();
	$clubcar_req       = get_option( 'require_name_email' );
	$clubcar_aria_req  = ( $clubcar_req ? " aria-required='true'" : '' );
	$clubcar_html5     = current_theme_supports( 'html5', 'comment-form' ) ? 1 : 0;
	$clubcar_fields    = array(
		'author' => '<div class="form-group comment-form-author"><input class="form-control" id="author" name="author" type="text" value="' . esc_attr( $clubcar_commenter['comment_author'] ) . '" placeholder="' . esc_attr( $clubcar_req ? '* ' : '' ) . esc_attr__( 'Name', 'clubcar' ) . '..." size="30"' . $clubcar_aria_req . ' /></div>',
		'email'  => '<div class="form-group comment-form-email"><input class="form-control" id="email" name="email" ' . ( $clubcar_html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $clubcar_commenter['comment_author_email'] ) . '" placeholder="' . esc_attr( $clubcar_req ? '* ' : '' ) . esc_attr__( 'Email', 'clubcar' ) . '..." size="30"' . $clubcar_aria_req . ' /></div>',
		'url'    => '<div class="form-group comment-form-url"><input class="form-control" id="url" name="url" ' . ( $clubcar_html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $clubcar_commenter['comment_author_url'] ) . '" placeholder="' . esc_attr__( 'Website', 'clubcar' ) . '..." size="30" /></div>',
	);
	return $clubcar_fields;
}
add_filter( 'comment_form_default_fields', 'clubcar_comment_form_fields' );

/**
 * Bootstrap Comment Form
 *
 * @param array $clubcar_args Comment Form Fields.
 */
function clubcar_comment_form( $clubcar_args ) {
	$clubcar_args['comment_field'] = '<div class="form-group comment-form-comment"><textarea class="form-control" id="comment" name="comment" cols="45" rows="8" placeholder="' . esc_attr__( 'Comment', 'clubcar' ) . '..." aria-required="true"></textarea></div>';
	$clubcar_args['class_submit']  = 'btn btn-default btn-submit';
	return $clubcar_args;
}
add_filter( 'comment_form_defaults', 'clubcar_comment_form' );

?>
