<?php
/**
 * The header for our theme including the navigation and the photo header
 *
 * @package ClubCar
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>"/>
<meta name="viewport" content="width=device-width, initial-scale=1.0" />
<link rel="profile" href="https://gmpg.org/xfn/11">
<?php if ( is_singular() && pings_open() ) : ?>
<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
<?php endif; ?>
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
if ( function_exists( 'wp_body_open' ) ) {
	wp_body_open();
}
?>

<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'clubcar' ); ?></a>

<div class="cursor cursor-1 position-fixed rounded-circle" id="cursor"></div>
<div class="cursor cursor-2 position-fixed rounded-circle" id="cursor2"></div>

<div class="top-bar py-2 position-relative">
	<div class="container-fluid">
		<div class="row">
			<div class="col-10 d-flex align-items-center">
				<?php get_template_part( 'inc/social' ); ?>
			</div>
			<div class="col-2 d-flex align-items-center">
			<?php if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) : ?>
				<?php $clubcar_count = WC()->cart->cart_contents_count; ?>
				<div class="woocommerce-cart-contents position-relative ms-auto rounded-circle">
					<a href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_attr__( 'View your shopping cart', 'clubcar' ); ?>" class="w-100 h-100 rounded-circle d-block">
						<i class="fas fa-shopping-bag"></i>
					<?php if ( $clubcar_count > 0 ) : ?>
						<span class="woocommerce-cart-contents-count"><?php echo esc_html( $clubcar_count ); ?></span>
					<?php endif; ?>
					</a>
				</div>
			<?php endif; ?>
			</div>
		</div>
	</div>
</div>

<nav class="navbar navbar-expand-lg">
	<div class="container-fluid">
			<a class="navbar-brand" href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
			<?php
			$clubcar_custom_logo_id = get_theme_mod( 'custom_logo' );
			$clubcar_logo           = wp_get_attachment_image_src( $clubcar_custom_logo_id, 'full' );
			$clubcar_description    = get_bloginfo( 'description', 'display' );
			?>
			<?php if ( has_custom_logo() ) : ?>
				<img src="<?php echo esc_url( $clubcar_logo[0] ); ?>" class="img-fluid">
			<?php else : ?>
				<span class="site-title fw-bold"><?php bloginfo( 'name' ); ?></span>
				<?php if ( $clubcar_description || is_customize_preview() ) : ?>
					<span class="site-description d-table"><?php echo esc_html( $clubcar_description ); ?></span>
				<?php endif; ?>
			<?php endif; ?>
			</a>
			<button class="navbar-toggler ml-auto border-0 rounded-0 collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
				<span class="navbar-toggler-line position-relative mb-1 rounded"></span>
				<span class="navbar-toggler-line position-relative mb-1 rounded"></span>
				<span class="navbar-toggler-line position-relative rounded"></span>
			</button>
			<div class="collapse navbar-collapse" id="navbarSupportedContent">
				<?php clubcar_bootstrap_menu(); ?>
			</div>
		</div>
	</div>
</nav>

<div class="site-header position-relative">
	<div class="container-fluid">
		<div class="row">
			<div class="col-12 col-md-10 offset-md-2 col-lg-10 offset-md-2 col-xl-10 offset-xl-2 position-relative">
		<?php if ( is_front_page() && is_home() && ! is_paged() ) : ?>
			<?php if ( have_posts() ) : ?>
				<?php
				$args = array(
					'posts_per_page' => '1',
					'post__not_in'   => get_option( 'sticky_posts' ),
				);
				query_posts( $args );
				?>
				<div class="site-header-extra position-absolute d-none d-lg-inline-block">
				<?php while ( have_posts() ) : ?>
					<?php the_post(); ?>
					<div class="row g-0">
					<?php if ( has_post_thumbnail() ) : ?>
						<div class="col-12">
							<div class="site-header-extra-image position-relative">
								<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
									<?php the_post_thumbnail( 'medium' ); ?>
									<div class="site-header-extra-image-overlay position-absolute">
										<div class="site-header-extra-image-overlay-arrow position-absolute"></div>
									</div>
								</a>
							</div>
						</div>
					<?php endif; ?>
						<div class="col-12 h-100">
							<div class="site-header-extra-info p-4">
								<div class="post-title position-relative mb-2">
									<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>" class="text-uppercase fw-bold"><?php the_title(); ?></a>
								</div>
								<div class="post-message">
									<?php the_excerpt(); ?>
								</div>
							</div>
						</div>
					</div>
				<?php endwhile; ?>
				<?php wp_reset_query(); ?>
				</div>
			<?php endif; ?>
		<?php endif; ?>
				<div class="site-header-info position-relative pb-5">
					<div class="row">
						<div class="col-12 col-md-10 offset-md-1 col-lg-6 offset-lg-1">
						<?php if ( is_front_page() && is_home() && ! is_paged() ) : ?>
							<?php if ( is_active_sidebar( 'header-sidebar' ) ) : ?>
								<?php dynamic_sidebar( 'header-sidebar' ); ?>
							<?php endif; ?>
						<?php else : ?>
							<?php if ( is_single() || is_page() ) : ?>
								<?php if ( have_posts() ) : ?>
									<?php while ( have_posts() ) : ?>
										<?php the_post(); ?>
										<h1><?php the_title(); ?></h1>
									<?php endwhile; ?>
								<?php else : ?>
								<?php endif; ?>
							<?php elseif ( is_category() ) : ?>
								<h1><?php esc_html_e( 'Latest Posts Under:', 'clubcar' ); ?> <?php single_cat_title(); ?></h1>
							<?php elseif ( is_search() ) : ?>
								<h1><?php esc_html_e( 'Search Results For:', 'clubcar' ); ?> <strong><?php echo get_search_query(); ?></strong></h1>
							<?php elseif ( is_archive() ) : ?>
								<?php if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) : ?>
									<?php if ( is_shop() ) : ?>
										<h1><?php woocommerce_page_title(); ?></h1>
									<?php else : ?>
										<h1><?php the_archive_title(); ?></h1>
									<?php endif; ?>
								<?php else : ?>
									<h1><?php the_archive_title(); ?></h1>
								<?php endif; ?>
							<?php elseif ( is_404() ) : ?>
								<h1><?php esc_html_e( 'The Page You Are Looking For Doesn&rsquo;t Exist.', 'clubcar' ); ?></h1>
							<?php endif; ?>
						<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="row">
			<div class="col-12 position-relative">
			<?php if ( get_header_image() || has_post_thumbnail() ) : ?>
				<?php if ( is_front_page() && is_home() && ! is_paged() ) : ?>
					<div class="site-header-image position-relative">
						<img src="<?php echo esc_url( header_image() ); ?>" class="img-fluid img-cover w-100 h-100 position-relative">
					</div>
				<?php elseif ( is_single() || is_page() ) : ?>
					<div class="site-header-image position-relative">
						<?php if ( has_post_thumbnail() ) : ?>
							<?php $backgroundimg = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' ); ?>
							<img src="<?php echo esc_url( $backgroundimg[0] ); ?>" class="img-fluid img-cover w-100 h-100 position-relative">
						<?php else : ?>
							<img src="<?php echo esc_url( header_image() ); ?>" class="img-fluid img-cover w-100 h-100 position-relative">
						<?php endif; ?>
						<?php if ( is_single() || is_page() ) : ?>
							<?php if ( have_posts() ) : ?>
								<?php while ( have_posts() ) : ?>
									<?php the_post(); ?>
									<?php get_template_part( 'inc/post', 'meta' ); ?>
								<?php endwhile; ?>
							<?php endif; ?>
						<?php endif; ?>
					</div>
				<?php endif; ?>
					<?php if ( is_front_page() && is_home() && ! is_paged() ) : ?>
						<div class="site-header-scroll position-absolute d-none d-md-block">
							<div class="site-header-scrolling position-absolute"></div>
							<div class="site-header-name position-absolute text-white text-uppercase fw-bold">Scroll</div>
						</div>
					<?php endif; ?>
				</div>
			<?php endif; ?>
			</div>
		</div>
	</div>
</div>

<?php if ( is_active_sidebar( 'primary_sidebar' ) ) : ?>
<section class="sidebar position-fixed">
	<div class="sidebar-button">
		<a class="btn btn-sidebar text-uppercase rounded-0"><?php esc_html_e( 'Sidebar', 'clubcar' ); ?></a>
	</div>
	<div class="sidebar-frame position-absolute bg-white border-left">
		<div class="sidebar-main p-3 p-sm-5">
			<?php get_sidebar(); ?>
		</div>
	</div>
</section>
<?php endif; ?>
